@@ -326,8 +326,6 @@ void MainWindow::on_pushButton_clicked()
             Icons = "Don't show icon backgrounds";
         }
 
-        writeSettings();
-
         if ( ui->saveasnew->checkState() == Qt::Checked ) {
 
 
@@ -367,7 +365,7 @@ void MainWindow::runscript(QString command)
                 muoks0->waitForFinished();
                 progress.setValue(5);
                 saveasnew = "0";
-
+                readgtkrc();
     }
 
     if ( command == "saveonly" ) {
@@ -395,10 +393,9 @@ void MainWindow::runscript(QString command)
         return;
 
     }
+    writeSettings();
 
-//        QMaemo5InformationBox::information(this, tr("Creating backups..."), 1);
     progress.setLabelText(tr("Creating backups..."));
-//        sleep(2);
     progress.setValue(6);
     progress.setValue(7);
     progress.setValue(8);
@@ -781,7 +778,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-44<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-45<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
