@@ -8,6 +8,10 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Current theme: </source>
+        <translation>Nykyinen teema: </translation>
+    </message>
     <message>
         <source>Export theme</source>
         <translation>Vie teema</translation>
